package com.zhongzheng.modules.course.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zhongzheng.modules.course.bo.CoursePhotoLogAddBo;
import com.zhongzheng.modules.course.bo.CoursePhotoLogEditBo;
import com.zhongzheng.modules.course.bo.CoursePhotoLogQueryBo;
import com.zhongzheng.modules.course.domain.CoursePhotoLog;
import com.zhongzheng.modules.course.vo.CoursePhotoLogVo;

import java.util.Collection;
import java.util.List;

/**
 * 用户节拍照记录Service接口
 *
 * @author hjl
 * @date 2022-01-12
 */
public interface ICoursePhotoLogService extends IService<CoursePhotoLog> {
	/**
	 * 查询单个
	 * @return
	 */
	CoursePhotoLogVo queryById(Long id);

	/**
	 * 查询列表
	 */
	List<CoursePhotoLogVo> queryList(CoursePhotoLogQueryBo bo);

	/**
	 * 根据新增业务对象插入用户节拍照记录
	 * @param bo 用户节拍照记录新增业务对象
	 * @return
	 */
	Boolean insertByAddBo(CoursePhotoLogAddBo bo);

	List<CoursePhotoLogVo> getLastInfo(CoursePhotoLogQueryBo bo);

	/**
	 * 根据编辑业务对象修改用户节拍照记录
	 * @param bo 用户节拍照记录编辑业务对象
	 * @return
	 */
	Boolean updateByEditBo(CoursePhotoLogEditBo bo);

	/**
	 * 校验并删除数据
	 * @param ids 主键集合
	 * @param isValid 是否校验,true-删除前校验,false-不校验
	 * @return
	 */
	Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);
}
